
#ifndef _C13_ds621_
#define _C13_ds621_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_REFERENCE F1031_6787(EIF_REFERENCE);
extern void EIF_Minit621(void);

#ifdef __cplusplus
}
#endif

#endif
